@@ -243,7 +243,7 @@ class LoginRequest(DSRequest):
             time.sleep(3)
             send()
         else:
-            if chat_user_user.props != props:
+            if chat_user_user.props._value != props:
                 chat_user_user.props = props
                 chat_user_user.save()
 
